#include <unistd.h>
#include <fcntl.h>
#include <sys/ioctl.h>

#include "iic.h"

static int
iic_exec(int fd, i2c_addr_t addr, i2c_op_t op, uint8_t *cmd, size_t cmdlen, uint8_t *buf, size_t buflen)
{
	i2c_ioctl_exec_t iie;

	iie.iie_op = op;
	iie.iie_addr = addr;
	iie.iie_cmd = cmd;
	iie.iie_cmdlen = cmdlen;
	iie.iie_buf = buf;
	iie.iie_buflen = buflen;

	return ioctl(fd, I2C_IOCTL_EXEC, &iie);
}

int
iic_open(IIC *hdl, const char *dev, i2c_addr_t addr)
{
	hdl->addr = addr;
	hdl->fd = open(dev, O_RDWR);
	return hdl->fd == -1;
}

int
iic_close(IIC *hdl)
{
	if (close(hdl->fd))
		return -1;

	hdl->fd = -1;
	return 0;
}

int
iic_read(IIC *hdl, uint8_t *cmd, size_t cmdlen, uint8_t *buf, size_t buflen)
{
	return iic_exec(hdl->fd, hdl->addr, I2C_OP_READ_WITH_STOP, cmd, cmdlen, buf, buflen);
}

int
iic_write(IIC *hdl, uint8_t *cmd, size_t cmdlen, uint8_t *buf, size_t buflen)
{
	return iic_exec(hdl->fd, hdl->addr, I2C_OP_WRITE_WITH_STOP, cmd, cmdlen, buf, buflen);
}

